import { Observable, Subject } from 'rxjs';
export declare type DetectedTheme = 'dark' | 'light';
export declare class ThemeService {
    private _theme;
    /**
     * A function that loads the saved theme.
     * Defaults to loading from local storage with the key `theme`.
     */
    loadHandler: () => string | null;
    /**
     * A function that saves the theme.
     * Defaults to saving to local storage with the key `theme`.
     *
     * @param theme
     *  the theme to save
     */
    saveHandler: (theme: string | null) => void;
    constructor(document: any);
    /**
     * @return a subject representing the currently active theme
     */
    get theme$(): Subject<string | null>;
    /**
     * @return `dark` if the user agent prefers dark color scheme, `light` otherwise
     */
    get detectedTheme(): DetectedTheme;
    /**
     * @return an observable version of {@link detectedTheme} that automatically updates on changes, e.g. when the user
     * changes their operating system theme preference, or it switches depending on day/night.
     */
    get detectedTheme$(): Observable<DetectedTheme>;
    /**
     * @return the current theme
     */
    get theme(): string | null;
    /**
     * @param value
     *  the new theme
     */
    set theme(value: string | null);
    /**
     * @return the saved theme, using {@link loadHandler}
     */
    get savedTheme(): string | null;
    /**
     * @param theme
     *  the theme to save using {@link saveHandler}
     */
    set savedTheme(theme: string | null);
}
